@@ -103,7 +103,7 @@ SUPPORTED_LANGUAGES = "en,fr,de,nl,es,pt,it,zh,ru,ja"
 
 
 class SpacyNERAnnotator(AnnotatorBase):
-    """[Spacy](https://spacy.io/api/entityrecognizer) annotator.
+    __doc__ = """[Spacy](https://spacy.io/api/entityrecognizer) annotator.
     #need-segments
     #languages:""" + SUPPORTED_LANGUAGES
 
